@@ -5,7 +5,7 @@ use Data::Object 'Class';
 use Type::Registry;
 use Test::More;
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 has parser => (
   is => 'ro',
@@ -282,6 +282,8 @@ method registry() {
 
 1;
 
+=encoding utf8
+
 =head1 NAME
 
 Test::Auto::Subtests
@@ -669,4 +671,26 @@ with a try/catch construct.
 
 =back
 
-=cut
\ No newline at end of file
+=cut
+
+=head1 AUTHOR
+
+Al Newkirk, C<awncorp@cpan.org>
+
+=head1 LICENSE
+
+Copyright (C) 2011-2019, Al Newkirk, et al.
+
+This is free software; you can redistribute it and/or modify it under the terms
+of the The Apache License, Version 2.0, as elucidated in the
+L<"license file"|https://github.com/iamalnewkirk/test-auto/blob/master/LICENSE>.
+
+=head1 PROJECT
+
+L<Project|https://github.com/iamalnewkirk/test-auto>
+
+L<Milestones|https://github.com/iamalnewkirk/test-auto/milestones>
+
+L<Issues|https://github.com/iamalnewkirk/test-auto/issues>
+
+=cut
